{
    "$graph": [
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "format": "http://edamontology.org/format_1929",
                    "id": "#make_search_pair_workflow.cwl/all_contig_fasta"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "format": "http://edamontology.org/format_1929",
                    "id": "#make_search_pair_workflow.cwl/all_protein_fasta"
                },
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "id": "#make_search_pair_workflow.cwl/contig_region"
                },
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "id": "#make_search_pair_workflow.cwl/protein"
                }
            ],
            "steps": [
                {
                    "run": "#samtools_faidx_extract.cwl",
                    "in": [
                        {
                            "source": "#make_search_pair_workflow.cwl/all_contig_fasta",
                            "id": "#make_search_pair_workflow.cwl/extract_contig/fasta_file"
                        },
                        {
                            "source": "#make_search_pair_workflow.cwl/contig_region",
                            "id": "#make_search_pair_workflow.cwl/extract_contig/region_file"
                        }
                    ],
                    "out": [
                        "#make_search_pair_workflow.cwl/extract_contig/extracted_fasta"
                    ],
                    "id": "#make_search_pair_workflow.cwl/extract_contig"
                },
                {
                    "run": "#samtools_faidx_extract.cwl",
                    "in": [
                        {
                            "source": "#make_search_pair_workflow.cwl/all_protein_fasta",
                            "id": "#make_search_pair_workflow.cwl/extract_protein/fasta_file"
                        },
                        {
                            "source": "#make_search_pair_workflow.cwl/protein",
                            "id": "#make_search_pair_workflow.cwl/extract_protein/region_file"
                        }
                    ],
                    "out": [
                        "#make_search_pair_workflow.cwl/extract_protein/extracted_fasta"
                    ],
                    "id": "#make_search_pair_workflow.cwl/extract_protein"
                }
            ],
            "id": "#make_search_pair_workflow.cwl",
            "outputs": [
                {
                    "type": "File",
                    "format": "$(inputs.all_contig_fasta.format)",
                    "outputSource": "#make_search_pair_workflow.cwl/extract_contig/extracted_fasta",
                    "id": "#make_search_pair_workflow.cwl/contig_fasta"
                },
                {
                    "type": "File",
                    "format": "$(inputs.all_protein_fasta.format)",
                    "outputSource": "#make_search_pair_workflow.cwl/extract_protein/extracted_fasta",
                    "id": "#make_search_pair_workflow.cwl/protein_fasta"
                }
            ]
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "label": "Genomic contigs (FASTA)",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#main/contigs_fasta"
                },
                {
                    "label": "Proteins (FASTA)",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#main/proteins_fasta"
                },
                {
                    "label": "Spaln species table to use (optional)",
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/species_table"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/process_spaln_output/combined_spaln_output",
                    "id": "#main/spaln_out"
                }
            ],
            "requirements": [
                {
                    "ramMin": 4096,
                    "coresMin": 1,
                    "class": "ResourceRequirement"
                }
            ],
            "steps": [
                {
                    "requirements": [
                        {
                            "class": "ScatterFeatureRequirement"
                        },
                        {
                            "class": "SubworkflowFeatureRequirement"
                        }
                    ],
                    "scatter": [
                        "#main/extract_region_pairs/contig_region",
                        "#main/extract_region_pairs/protein"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#make_search_pair_workflow.cwl",
                    "in": [
                        {
                            "source": "#main/samtools_index_contigs/sequences_with_index",
                            "id": "#main/extract_region_pairs/all_contig_fasta"
                        },
                        {
                            "source": "#main/samtools_index_protein/sequences_with_index",
                            "id": "#main/extract_region_pairs/all_protein_fasta"
                        },
                        {
                            "source": "#main/extract_region_specs/contig_regions_files",
                            "id": "#main/extract_region_pairs/contig_region"
                        },
                        {
                            "source": "#main/extract_region_specs/proteins_lists",
                            "id": "#main/extract_region_pairs/protein"
                        }
                    ],
                    "out": [
                        "#main/extract_region_pairs/contig_fasta",
                        "#main/extract_region_pairs/protein_fasta"
                    ],
                    "id": "#main/extract_region_pairs"
                },
                {
                    "run": "#metaeuk_to_regions.cwl",
                    "in": [
                        {
                            "source": "#main/metaeuk/output_fasta",
                            "id": "#main/extract_region_specs/metaeuk_fasta"
                        }
                    ],
                    "out": [
                        "#main/extract_region_specs/contig_regions_files",
                        "#main/extract_region_specs/proteins_lists"
                    ],
                    "id": "#main/extract_region_specs"
                },
                {
                    "run": "#metaeuk_easy_predict.cwl",
                    "in": [
                        {
                            "source": "#main/contigs_fasta",
                            "id": "#main/metaeuk/contigs"
                        },
                        {
                            "source": "#main/proteins_fasta",
                            "id": "#main/metaeuk/query"
                        }
                    ],
                    "out": [
                        "#main/metaeuk/output_fasta"
                    ],
                    "id": "#main/metaeuk"
                },
                {
                    "run": "#process_spaln_output.cwl",
                    "in": [
                        {
                            "source": "#main/spaln/spaln_out",
                            "id": "#main/process_spaln_output/spaln_outputs"
                        }
                    ],
                    "out": [
                        "#main/process_spaln_output/combined_spaln_output"
                    ],
                    "id": "#main/process_spaln_output"
                },
                {
                    "run": "#samtools_faidx.cwl",
                    "in": [
                        {
                            "source": "#main/contigs_fasta",
                            "id": "#main/samtools_index_contigs/sequences"
                        }
                    ],
                    "out": [
                        "#main/samtools_index_contigs/sequences_with_index"
                    ],
                    "id": "#main/samtools_index_contigs"
                },
                {
                    "run": "#samtools_faidx.cwl",
                    "in": [
                        {
                            "source": "#main/proteins_fasta",
                            "id": "#main/samtools_index_protein/sequences"
                        }
                    ],
                    "out": [
                        "#main/samtools_index_protein/sequences_with_index"
                    ],
                    "id": "#main/samtools_index_protein"
                },
                {
                    "requirements": [
                        {
                            "class": "ScatterFeatureRequirement"
                        }
                    ],
                    "scatter": [
                        "#main/spaln/genome_fasta",
                        "#main/spaln/query_fasta"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#spaln.cwl",
                    "in": [
                        {
                            "source": "#main/extract_region_pairs/contig_fasta",
                            "id": "#main/spaln/genome_fasta"
                        },
                        {
                            "default": 0,
                            "id": "#main/spaln/output_format"
                        },
                        {
                            "source": "#main/extract_region_pairs/protein_fasta",
                            "id": "#main/spaln/query_fasta"
                        },
                        {
                            "source": "#main/species_table",
                            "id": "#main/spaln/species"
                        }
                    ],
                    "out": [
                        "#main/spaln/spaln_out"
                    ],
                    "id": "#main/spaln"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/metaeuk:2.ddf2742--h2d02072_0",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "version": [
                                "2.ddf2742"
                            ],
                            "specs": [
                                "https://github.com/soedinglab/metaeuk"
                            ],
                            "package": "metaeuk"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 10
                    },
                    "id": "#metaeuk_easy_predict.cwl/contigs"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--metaeuk-eval"
                    },
                    "id": "#metaeuk_easy_predict.cwl/eval"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--max-intron"
                    },
                    "id": "#metaeuk_easy_predict.cwl/max_intron"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--metaeuk-tcov"
                    },
                    "id": "#metaeuk_easy_predict.cwl/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--min-intron"
                    },
                    "id": "#metaeuk_easy_predict.cwl/min_intron"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--min-length"
                    },
                    "id": "#metaeuk_easy_predict.cwl/min_length"
                },
                {
                    "type": "string",
                    "default": "metaeuk_output.fasta",
                    "inputBinding": {
                        "position": 30
                    },
                    "id": "#metaeuk_easy_predict.cwl/output_name"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 20
                    },
                    "id": "#metaeuk_easy_predict.cwl/query"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-e"
                    },
                    "id": "#metaeuk_easy_predict.cwl/segment_eval"
                },
                {
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "valueFrom": "$(self ? self : runtime.tmpdir)",
                        "position": 40
                    },
                    "id": "#metaeuk_easy_predict.cwl/temp_dir"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--threads"
                    },
                    "id": "#metaeuk_easy_predict.cwl/threads"
                }
            ],
            "baseCommand": [
                "metaeuk",
                "easy-predict"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "$(inputs.contigs.format)",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#metaeuk_easy_predict.cwl/output_fasta"
                }
            ],
            "id": "#metaeuk_easy_predict.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "python:3.8-slim-buster",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "python"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "number of bases to add to the start and end of the region to extract",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#metaeuk_to_regions.cwl/fuzz_length"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#metaeuk_to_regions.cwl/metaeuk_fasta"
                },
                {
                    "type": "File",
                    "default": {
                        "class": "File",
                        "basename": "extract_regions.py",
                        "contents": "from __future__ import print_function, division\nimport sys\n\ninput_filename = sys.argv[1]\nif len(sys.argv) == 3:\n    fuzz = int(sys.argv[2])\nelse:\n    fuzz = 0\ninput_file = open(input_filename)\n\ncount = 0\nfor line in input_file:\n    if not line.startswith(\">\"):\n        continue\n    count += 1\n    contig_regions_file = open(\"contig_regions{}.txt\".format(count), \"w\")\n    proteins_list_file = open(\"proteins{}.txt\".format(count), \"w\")\n    fields = line.split(\"|\")\n    protein_id = fields[0][1:]\n    contig_id = fields[1]\n    r_start = int(fields[6])\n    if r_start > fuzz:\n        r_start = r_start - fuzz\n    r_end = int(fields[7]) + fuzz\n    print(\"{}:{}-{}\".format(contig_id, r_start, r_end), file=contig_regions_file)\n    print(protein_id, file=proteins_list_file)\n    contig_regions_file.close()\n    proteins_list_file.close()\n"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#metaeuk_to_regions.cwl/scripts"
                }
            ],
            "baseCommand": [
                "python"
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "outputBinding": {
                        "glob": "contig_regions*.txt"
                    },
                    "id": "#metaeuk_to_regions.cwl/contig_regions_files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "outputBinding": {
                        "glob": "proteins*.txt"
                    },
                    "id": "#metaeuk_to_regions.cwl/proteins_lists"
                }
            ],
            "id": "#metaeuk_to_regions.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "python:3.8-slim-buster",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "python"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "default": {
                        "class": "File",
                        "basename": "process_spaln_output.py",
                        "contents": "from __future__ import print_function, division\nfrom operator import itemgetter\nimport re\nimport sys\n\n\ndef fix(attrs, region_name, number):\n    id_re = re.compile(r\"(\\D+)(\\d+)\")\n    attr_kv = dict(map(lambda x: x.split(\"=\"), attrs.split(\";\")))\n    id_match = id_re.match(attr_kv[\"ID\"])\n    assert id_match is not None, \"Could not match ID from {}\".format(attrs)\n    type_str = id_match.group(1)\n    attr_kv[\"ID\"] = id_match.group(1) + \"{:05}\".format(number)\n    if \"Parent\" in attr_kv:\n        attr_kv[\"ID\"] = type_str + \"{}_{}\".format(number, id_match.group(2))\n        if type_str == \"mRNA\":\n            attr_kv[\"Parent\"] = \"gene{:05}\".format(number)\n        else:\n            attr_kv[\"Parent\"] = re.sub(\n                r\"(\\D+)(\\d+)\", r\"mRNA{}_\\2\".format(number), attr_kv[\"Parent\"]\n            )\n    else:\n        attr_kv[\"ID\"] = type_str + \"{:05}\".format(number)\n    attr_kv[\"Name\"] = region_name + \"_\" + str(number)\n    new_attrs = \"\"\n    for keyword in (\"ID\", \"Parent\", \"Name\", \"Target\"):\n        if keyword in attr_kv:\n            new_attrs += keyword + \"=\" + attr_kv[keyword] + \";\"\n    new_attrs = new_attrs.rstrip(\";\") + \"\\n\"\n    return new_attrs\n\n\noutput_filename = \"spaln_out.gff3\"\noutput_file = open(output_filename, \"w\")\nprint('##gff-version\\t3', file=output_file)\ninput_filenames = sys.argv[1:]\nseen_header = False\ngene_number = 0\nannotation_parts = {}\nstart_position = {}\nend_position = {}\nmax_end = 0\nfor input_filename in input_filenames:\n    for line in open(input_filename):\n        if line.startswith('##sequence-region'):\n            parts = line.split()\n            orig_region_name = parts[1]\n            location_parts = parts[1].split(\":\")\n            region_name = location_parts[0]\n            start = int(location_parts[1].split(\"-\")[0])\n            if region_name not in annotation_parts:\n                annotation_parts[region_name] = []\n            annotation_parts[region_name].append((start, region_name, input_filename))\n        elif not line.startswith('#'):\n            fields = line.rstrip().split(\"\\t\")\n            seq_type = fields[2]\n            if seq_type == 'gene':\n                # end is fields[4]\n                max_end = int(fields[4]) + start\n    else:\n        if region_name not in end_position or end_position[region_name] < max_end:\n            end_position[region_name] = max_end\n        if region_name not in start_position or start_position[region_name] > start:\n            start_position[region_name] = start\n\nfor annotation_part, locations in sorted(annotation_parts.items(), key=itemgetter(1)):\n    # locations is a list of tupes (starting_position, region_name, filename)\n    sequence_region_added = False\n    for start, region_name, input_filename in sorted(locations, key=itemgetter(0)):\n        if not sequence_region_added:\n            assert start == start_position[region_name], \"mismatch between this start position {} and computed start position {} for {}\".format(start, start_position[region_name], region_name)\n            # started a new contig, add a sequence region header that describes the region under annotation\n            print('##sequence-region\\t{} {} {}'.format(region_name, start, end_position[region_name]), file=output_file)\n            sequence_region_added = True\n\n        for line in open(input_filename):\n            if line.startswith(\"##sequence-region\") or line.startswith('##gff-version'):\n                continue\n            elif line.startswith('##FASTA'):\n                break\n            elif line.startswith('##'):\n                print('Warning: unexpected directive {}'.format(line.strip()), file=output_file)\n                continue\n            fields = line.rstrip().split(\"\\t\")\n            seq_type = fields[2]\n            if seq_type == \"gene\":\n                gene_number += 1\n            fields[0] = region_name\n            fields[3] = str(int(fields[3]) + start)\n            fields[4] = str(int(fields[4]) + start)\n            fields[8] = fix(fields[8], region_name, gene_number)\n            new_line = \"\\t\".join(fields)\n            print(new_line, end=\"\", file=output_file)\noutput_file.close()\n"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#process_spaln_output.cwl/script"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#process_spaln_output.cwl/spaln_outputs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "spaln_out.gff3"
                    },
                    "id": "#process_spaln_output.cwl/combined_spaln_output"
                }
            ],
            "baseCommand": [
                "python"
            ],
            "id": "#process_spaln_output.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.10--h2e538c0_3",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "samtools",
                            "version": [
                                "1.10"
                            ],
                            "specs": [
                                "https://bio.tools/samtools"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Continue after trying to retrieve missing region",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--continue"
                    },
                    "id": "#samtools_faidx_extract.cwl/continue"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "inputBinding": {
                        "position": 10
                    },
                    "id": "#samtools_faidx_extract.cwl/fasta_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Length of FASTA sequence line",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--length"
                    },
                    "id": "#samtools_faidx_extract.cwl/line_length"
                },
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--region-file"
                    },
                    "id": "#samtools_faidx_extract.cwl/region_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Reverse complement sequences",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--reverse-complement"
                    },
                    "id": "#samtools_faidx_extract.cwl/reverse_complement"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "How to add strand indicator to sequence name",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--mark-strand"
                    },
                    "id": "#samtools_faidx_extract.cwl/strand_mark"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "$(inputs.fasta_file.format)",
                    "outputBinding": {
                        "glob": "output.fasta"
                    },
                    "id": "#samtools_faidx_extract.cwl/extracted_fasta"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "output.fasta",
                    "prefix": "--output",
                    "position": 1
                }
            ],
            "baseCommand": [
                "samtools",
                "faidx"
            ],
            "id": "#samtools_faidx_extract.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/spaln:2.4.03--pl526he513fc3_0",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "spaln",
                            "version": [
                                "2.4.03"
                            ],
                            "specs": [
                                "https://github.com/ogotoh/spaln"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 10
                    },
                    "id": "#spaln.cwl/genome_fasta"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-O"
                    },
                    "id": "#spaln.cwl/output_format"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 20
                    },
                    "id": "#spaln.cwl/query_fasta"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-T"
                    },
                    "id": "#spaln.cwl/species"
                }
            ],
            "stdout": "spaln_output.txt",
            "outputs": [
                {
                    "type": "File",
                    "id": "#spaln.cwl/spaln_out",
                    "outputBinding": {
                        "glob": "spaln_output.txt"
                    }
                }
            ],
            "baseCommand": [
                "spaln"
            ],
            "id": "#spaln.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.14--hb421002_0",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        "$(inputs.sequences)"
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "faidx"
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input FASTA file",
                    "format": "https://edamontology.org/format_1929",
                    "id": "#samtools_faidx.cwl/sequences"
                }
            ],
            "arguments": [
                "$(inputs.sequences.basename)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename).fai"
                    },
                    "id": "#samtools_faidx.cwl/sequences_index"
                },
                {
                    "type": "File",
                    "format": "$(inputs.sequences.format)",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename)"
                    },
                    "id": "#samtools_faidx.cwl/sequences_with_index"
                }
            ],
            "id": "#samtools_faidx.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.18.owl",
        "https://edamontology.org/EDAM_1.18.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "bio-cwl-tools": "https://raw.githubusercontent.com/common-workflow-library/bio-cwl-tools/release/"
    }
}
